@@ -31,7 +31,6 @@
 #include <QObject>
 #include <QVector>
 #include <QFontMetricsF>
-#include <QStringListModel>
 
 class KConfigGroup;
 namespace KTextEditor { class ViewPrivate; }
@@ -504,9 +503,6 @@ public:
 
     int maxHistorySize() const;
 
-    QStringListModel *patternHistoryModel();
-    QStringListModel *replacementHistoryModel();
-
     uint defaultMarkType() const;
     void setDefaultMarkType(uint type);
 
@@ -556,6 +552,9 @@ public:
     bool scrollPastEnd() const;
     void setScrollPastEnd(bool on);
 
+    bool foldFirstLine() const;
+    void setFoldFirstLine(bool on);
+
 private:
     bool m_dynWordWrap;
     int m_dynWordWrapIndicators;
@@ -573,8 +572,6 @@ private:
     int m_autoCenterLines;
     long m_searchFlags;
     int m_maxHistorySize;
-    QStringListModel m_patternHistoryModel;
-    QStringListModel m_replacementHistoryModel;
     uint m_defaultMarkType;
     bool m_persistentSelection;
     KTextEditor::View::InputMode m_inputMode;
@@ -587,6 +584,7 @@ private:
     bool m_wordCompletionRemoveTail;
     bool m_smartCopyCut;
     bool m_scrollPastEnd;
+    bool m_foldFirstLine;
 
     bool m_dynWordWrapSet : 1;
     bool m_dynWordWrapIndicatorsSet : 1;
@@ -616,6 +614,7 @@ private:
     bool m_scrollPastEndSet : 1;
     bool m_allowMarkMenu : 1;
     bool m_wordCompletionRemoveTailSet : 1;
+    bool m_foldFirstLineSet : 1;
 
 private:
     static KateViewConfig *s_global;
