@@ -26,8 +26,6 @@
 #include <ktexteditor/texthintinterface.h>
 #include <ktexteditor/markinterface.h>
 #include <ktexteditor/codecompletioninterface.h>
-#include <draft/templateinterface.h>
-#include <draft/templateinterface2.h>
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/annotationinterface.h>
 #include <ktexteditor/mainwindow.h>
@@ -35,6 +33,7 @@
 #include <QPointer>
 #include <QModelIndex>
 #include <QMenu>
+#include <QSpacerItem>
 
 #include "katetextrange.h"
 #include "katetextfolding.h"
@@ -68,6 +67,7 @@ class KToggleAction;
 class KSelectAction;
 
 class QAction;
+class QGridLayout;
 class QVBoxLayout;
 
 namespace KTextEditor
@@ -78,15 +78,12 @@ namespace KTextEditor
 //
 class KTEXTEDITOR_EXPORT ViewPrivate : public KTextEditor::View,
     public KTextEditor::TextHintInterface,
-    public KTextEditor::TemplateInterface2,
     public KTextEditor::CodeCompletionInterface,
     public KTextEditor::ConfigInterface,
     public KTextEditor::AnnotationViewInterface
 {
     Q_OBJECT
     Q_INTERFACES(KTextEditor::TextHintInterface)
-    Q_INTERFACES(KTextEditor::TemplateInterface)
-    Q_INTERFACES(KTextEditor::TemplateInterface2)
     Q_INTERFACES(KTextEditor::ConfigInterface)
     Q_INTERFACES(KTextEditor::CodeCompletionInterface)
     Q_INTERFACES(KTextEditor::AnnotationViewInterface)
@@ -96,7 +93,7 @@ class KTEXTEDITOR_EXPORT ViewPrivate : public KTextEditor::View,
     friend class ::KateIconBorder;
 
 public:
-    ViewPrivate (KTextEditor::DocumentPrivate *doc, QWidget *parent, KTextEditor::MainWindow *mainWindow = nullptr);
+    ViewPrivate (KTextEditor::DocumentPrivate *doc, QWidget *parent, KTextEditor::MainWindow *mainWindow = Q_NULLPTR);
     ~ViewPrivate ();
 
     /**
@@ -473,7 +470,7 @@ public Q_SLOTS:
 public:
     /**
      * Read session settings from the given \p config.
-     * 
+     *
      * Known flags:
      *  "SkipUrl" => don't save/restore the file
      *  "SkipMode" => don't save/restore the mode
@@ -585,6 +582,8 @@ public:
 public:
     void slotTextInserted(KTextEditor::View *view, const KTextEditor::Cursor &position, const QString &text);
 
+    void exportHtmlToFile(const QString &file);
+
 private Q_SLOTS:
     void slotGotFocus();
     void slotLostFocus();
@@ -601,6 +600,7 @@ public Q_SLOTS: // TODO: turn into good interface, see kte5/foldinginterface.h
     void slotExpandLocal();
 
 private:
+    void setupLayout();
     void setupConnections();
     void setupActions();
     void setupEditActions();
@@ -649,7 +649,11 @@ private:
     KateSpellCheckDialog  *m_spell;
     KateBookmarks    *const m_bookmarks;
 
-    QVBoxLayout *m_vBox;
+    //* margins
+    QSpacerItem *m_topSpacer;
+    QSpacerItem *m_leftSpacer;
+    QSpacerItem *m_rightSpacer;
+    QSpacerItem *m_bottomSpacer;
 
 private Q_SLOTS:
     void slotHlChanged();
@@ -682,12 +686,12 @@ private:
     // do we select normal or blockwise ?
     bool blockSelect;
 
-    //
-    // TemplateInterface + TemplateInterface2
-    //
+    // templates
 public:
-    virtual bool insertTemplateTextImplementation(const KTextEditor::Cursor &, const QString &templateString, const QMap<QString, QString> &initialValues);
-    virtual bool insertTemplateTextImplementation(const KTextEditor::Cursor &, const QString &templateString, const QMap<QString, QString> &initialValues, KTextEditor::TemplateScript *templateScript);
+    bool insertTemplateInternal(const KTextEditor::Cursor& insertPosition,
+                                const QString& templateString,
+                                const QString& script = QString());
+
     /**
      * Accessors to the bars...
      */
@@ -720,6 +724,9 @@ Q_SIGNALS:
     void displayRangeChanged(KTextEditor::ViewPrivate *view);
 
 protected:
+    virtual bool event(QEvent *e);
+    virtual void paintEvent(QPaintEvent *e);
+
     KToggleAction               *m_toggleOnTheFlySpellCheck;
     KateSpellingMenu *m_spellingMenu;
 
@@ -747,16 +754,16 @@ private Q_SLOTS:
     void applyFoldingState();
 
     void clearHighlights();
+    void createHighlights();
 
 private:
     void selectionChangedForHighlights();
-    void createHighlights();
-    
+
     /**
      * saved folding state
      */
     QVariantList m_savedFoldingState;
-    
+
     QString m_currentTextForHighlights;
 
     QList<KTextEditor::MovingRange*> m_rangesForHighlights;
@@ -923,6 +930,11 @@ private:
      */
     KateModeMenu *m_modeAction;
 
+    /**
+     * is automatic invocation of completion disabled temporarily?
+     */
+    bool m_temporaryAutomaticInvocationDisabled;
+
 public:
     /**
      * Returns the attribute for the default style \p defaultStyle.
